import{h as c,a1 as s,b as l,E as _}from"./C9jiJh7I.js";import{B as i}from"./CShESTQI.js";function b(a,n,o){c&&s();var r=new i(a);l(()=>{var e=n()??null;r.ensure(e,e&&(t=>o(t,e)))},_)}const f=Object.freeze(Object.defineProperty({__proto__:null},Symbol.toStringTag,{value:"Module"}));export{f as _,b as c};
