import{a7 as M,av as T,ab as S,ay as C,a8 as E,j as P,q as x,b6 as I,s as b,aG as d,b7 as O,b8 as L,b9 as D,h as _,w as c,ba as V,a1 as F,bb as R,a5 as W}from"./C9jiJh7I.js";const j=/\r/g;function K(e){e=e.replace(j,"");let t=5381,r=e.length;for(;r--;)t=(t<<5)-t^e.charCodeAt(r);return(t>>>0).toString(36)}function Q(e){return e.endsWith("capture")&&e!=="gotpointercapture"&&e!=="lostpointercapture"}const q=["beforeinput","click","change","dblclick","contextmenu","focusin","focusout","input","keydown","keyup","mousedown","mousemove","mouseout","mouseover","mouseup","pointerdown","pointermove","pointerout","pointerover","pointerup","touchend","touchmove","touchstart"];function Y(e){return q.includes(e)}const B={formnovalidate:"formNoValidate",ismap:"isMap",nomodule:"noModule",playsinline:"playsInline",readonly:"readOnly",defaultvalue:"defaultValue",defaultchecked:"defaultChecked",srcobject:"srcObject",novalidate:"noValidate",allowfullscreen:"allowFullscreen",disablepictureinpicture:"disablePictureInPicture",disableremoteplayback:"disableRemotePlayback"};function Z(e){return e=e.toLowerCase(),B[e]??e}const G=["touchstart","touchmove"];function ee(e){return G.includes(e)}function te(e){return e?.replace(/\//g,"/​")}const U=new Set,$=new Set;function N(e,t,r,i={}){function n(a){if(i.capture||z.call(t,a),!a.cancelBubble)return I(()=>r?.call(this,a))}return e.startsWith("pointer")||e.startsWith("touch")||e==="wheel"?x(()=>{t.addEventListener(e,n,i)}):t.addEventListener(e,n,i),n}function re(e,t,r,i={}){var n=N(t,e,r,i);return()=>{e.removeEventListener(t,n,i)}}function ae(e,t,r,i,n){var a={capture:i,passive:n},o=N(e,t,r,a);(t===document.body||t===window||t===document||t instanceof HTMLMediaElement)&&P(()=>{t.removeEventListener(e,o,a)})}function ne(e){for(var t=0;t<e.length;t++)U.add(e[t]);for(var r of $)r(e)}let k=null;function z(e){var t=this,r=t.ownerDocument,i=e.type,n=e.composedPath?.()||[],a=n[0]||e.target;k=e;var o=0,f=k===e&&e.__root;if(f){var s=n.indexOf(f);if(s!==-1&&(t===document||t===window)){e.__root=t;return}var l=n.indexOf(t);if(l===-1)return;s<=l&&(o=s)}if(a=n[o]||e.target,a!==t){M(e,"currentTarget",{configurable:!0,get(){return a||r}});var h=C,m=E;T(null),S(null);try{for(var v,w=[];a!==null;){var g=a.assignedSlot||a.parentNode||a.host||null;try{var y=a["__"+i];y!=null&&(!a.disabled||e.target===a)&&y.call(a,e)}catch(p){v?w.push(p):v=p}if(e.cancelBubble||g===t||g===null)break;a=g}if(v){for(let p of w)queueMicrotask(()=>{throw p});throw v}}finally{e.__root=t,delete e.currentTarget,T(h),S(m)}}}function A(e){var t=document.createElement("template");return t.innerHTML=e.replaceAll("<!>","<!---->"),t.content}function u(e,t){var r=E;r.nodes_start===null&&(r.nodes_start=e,r.nodes_end=t)}function oe(e,t){var r=(t&L)!==0,i=(t&D)!==0,n,a=!e.startsWith("<!>");return()=>{if(_)return u(c,null),c;n===void 0&&(n=A(a?e:"<!>"+e),r||(n=d(n)));var o=i||O?document.importNode(n,!0):n.cloneNode(!0);if(r){var f=d(o),s=o.lastChild;u(f,s)}else u(o,o);return o}}function H(e,t,r="svg"){var i=!e.startsWith("<!>"),n=(t&L)!==0,a=`<${r}>${i?e:"<!>"+e}</${r}>`,o;return()=>{if(_)return u(c,null),c;if(!o){var f=A(a),s=d(f);if(n)for(o=document.createDocumentFragment();d(s);)o.appendChild(d(s));else o=d(s)}var l=o.cloneNode(!0);if(n){var h=d(l),m=l.lastChild;u(h,m)}else u(l,l);return l}}function ie(e,t){return H(e,t,"svg")}function ue(e=""){if(!_){var t=b(e+"");return u(t,t),t}var r=c;return r.nodeType!==R&&(r.before(r=b()),W(r)),u(r,r),r}function se(){if(_)return u(c,null),c;var e=document.createDocumentFragment(),t=document.createComment(""),r=b();return e.append(t,r),u(t,r),e}function le(e,t){if(_){var r=E;((r.f&V)===0||r.nodes_end===null)&&(r.nodes_end=c),F();return}e!==null&&e.before(t)}const X="5";typeof window<"u"&&((window.__svelte??={}).v??=new Set).add(X);export{le as a,ie as b,se as c,ne as d,ae as e,oe as f,U as g,z as h,ee as i,u as j,A as k,K as l,Q as m,N as n,Z as o,Y as p,re as q,$ as r,te as s,ue as t};
