import{f as n,a as l}from"./C5_K9giE.js";import{c as i,r as p,t as m}from"./C9jiJh7I.js";import{s as f}from"./C49ripYd.js";import{p as c}from"./CdWcIaq1.js";import{I as d}from"./D3Rjo6U9.js";var h=n("<span><!></span>");function w(o,a){let e=c(a,"sizeClass",3,"w-4 h-4");var s=h();let r;var t=i(s);d(t,{icon:"lucide:chevron-down",get class(){return e()}}),p(s),m(()=>r=f(s,1,`inline-flex ${e()} transition-transform`,null,r,{"-rotate-90":!a.expanded})),l(o,s)}export{w as C};
