.tag-editor.svelte-6zz63t .tag-input{box-sizing:border-box}.width-resize-handle.svelte-ab9tpx{position:absolute;top:0;right:-3px;width:6px;height:100%;cursor:ew-resize;border-radius:999px}.width-resize-handle.svelte-ab9tpx:hover,.height-resize-handle.svelte-ab9tpx:hover{background:#26a69a33}.height-resize-handle.svelte-ab9tpx{position:absolute;bottom:-3px;left:0;width:100%;height:6px;cursor:ns-resize;border-radius:999px}.source-chip.svelte-ab9tpx{display:inline-flex;align-items:center;padding:2px 6px;border-radius:4px;font-size:10px;font-weight:600;text-transform:uppercase;letter-spacing:.05em}.svelte-flow__node-group{border:none!important;background:transparent!important;box-shadow:none!important;width:auto!important;height:auto!important}.width-resize-handle.svelte-cv51mr{position:absolute;top:0;right:-3px;width:6px;height:100%;cursor:ew-resize;border-radius:999px;z-index:10;pointer-events:auto}.width-resize-handle.svelte-cv51mr:hover,.height-resize-handle.svelte-cv51mr:hover{background:#26a69a33}.height-resize-handle.svelte-cv51mr{position:absolute;bottom:-3px;left:0;width:100%;height:6px;cursor:ns-resize;border-radius:999px;z-index:10;pointer-events:auto}
