import{c as m,a as t,f as l}from"../chunks/C5_K9giE.js";import{z as f,t as i}from"../chunks/C9jiJh7I.js";import{s as p}from"../chunks/CVpE0GVK.js";import{h as c,a as _}from"../chunks/C49ripYd.js";import{l as u}from"../chunks/BEE54Om4.js";const d=!0,h=!1,x=Object.freeze(Object.defineProperty({__proto__:null,prerender:d,ssr:h},Symbol.toStringTag,{value:"Module"}));var v=l('<link rel="icon" type="image/svg+xml"/>');function z(o,a){var e=m();c("12qhfyh",n=>{var r=v();i(()=>_(r,"href",u)),t(n,r)});var s=f(e);p(s,()=>a.children),t(o,e)}export{z as component,x as universal};
