import{b as U,h as R,a1 as Y,E as $,a2 as C,a3 as F,a4 as G,a5 as H,a6 as T,V as y,Z as V,D as P,G as v,j as Z,H as A,a7 as q,a8 as E,a9 as z,aa as D,ab as I,ac as N,ad as d,S as L,ae as B,af as m,ag as J,T as Q,ah as W,C as X,ai as k,aj as ee,ak as re,u as ne,al as se,am as ie,an as ue,ao as te,ap as ae}from"./C9jiJh7I.js";import{B as fe}from"./CShESTQI.js";import{s as le,g as oe}from"./CiWU5d2F.js";function Pe(e,r,s=!1){R&&Y();var n=new fe(e),i=s?$:0;function t(f,a){if(R){const b=C(e)===F;if(f===b){var l=G();H(l),n.anchor=l,T(!1),n.ensure(f,a),T(!0);return}}n.ensure(f,a)}U(()=>{var f=!1;r((a,l=!0)=>{f=!0,t(l,a)}),f||t(!1,null)},i)}let S=!1,x=Symbol();function we(e,r,s){const n=s[r]??={store:null,source:V(void 0),unsubscribe:y};if(P&&(n.source.label=r),n.store!==e&&!(x in s))if(n.unsubscribe(),n.store=e??null,e==null)n.source.v=void 0,n.unsubscribe=y;else{var i=!0;n.unsubscribe=le(e,t=>{i?n.source.v=t:A(n.source,t)}),i=!1}return e&&x in s?oe(e):v(n.source)}function me(e,r){return e.set(r),r}function xe(){const e={};function r(){Z(()=>{for(var s in e)e[s].unsubscribe();q(e,x,{enumerable:!1,value:!0})})}return[e,r]}function Ee(e,r,s){return e.set(s),r}function ce(e){var r=S;try{return S=!1,[e(),S]}finally{S=r}}const pe={get(e,r){if(!e.exclude.includes(r))return e.props[r]},set(e,r){return P&&ae(`${e.name}.${String(r)}`),!1},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function Oe(e,r,s){return new Proxy(P?{props:e,exclude:r,name:s,other:{},to_proxy:[]}:{props:e,exclude:r},pe)}const _e={get(e,r){if(!e.exclude.includes(r))return v(e.version),r in e.special?e.special[r]():e.props[r]},set(e,r,s){if(!(r in e.special)){var n=E;try{I(e.parent_effect),e.special[r]=ve({get[r](){return e.props[r]}},r,N)}finally{I(n)}}return e.special[r](s),D(e.version),!0},getOwnPropertyDescriptor(e,r){if(!e.exclude.includes(r)&&r in e.props)return{enumerable:!0,configurable:!0,value:e.props[r]}},deleteProperty(e,r){return e.exclude.includes(r)||(e.exclude.push(r),D(e.version)),!0},has(e,r){return e.exclude.includes(r)?!1:r in e.props},ownKeys(e){return Reflect.ownKeys(e.props).filter(r=>!e.exclude.includes(r))}};function ge(e,r){return new Proxy({props:e,exclude:r,special:{},version:z(0),parent_effect:E},_e)}const de={get(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(d(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n)return n[r]}},set(e,r,s){let n=e.props.length;for(;n--;){let i=e.props[n];d(i)&&(i=i());const t=m(i,r);if(t&&t.set)return t.set(s),!0}return!1},getOwnPropertyDescriptor(e,r){let s=e.props.length;for(;s--;){let n=e.props[s];if(d(n)&&(n=n()),typeof n=="object"&&n!==null&&r in n){const i=m(n,r);return i&&!i.configurable&&(i.configurable=!0),i}}},has(e,r){if(r===L||r===B)return!1;for(let s of e.props)if(d(s)&&(s=s()),s!=null&&r in s)return!0;return!1},ownKeys(e){const r=[];for(let s of e.props)if(d(s)&&(s=s()),!!s){for(const n in s)r.includes(n)||r.push(n);for(const n of Object.getOwnPropertySymbols(s))r.includes(n)||r.push(n)}return r}};function Re(...e){return new Proxy({props:e},de)}function ve(e,r,s,n){var i=!se||(s&ie)!==0,t=(s&re)!==0,f=(s&te)!==0,a=n,l=!0,b=()=>(l&&(l=!1,a=f?ne(n):n),a),p;if(t){var j=L in e||B in e;p=m(e,r)?.set??(j&&r in e?u=>e[r]=u:void 0)}var _,O=!1;t?[_,O]=ce(()=>e[r]):_=e[r],_===void 0&&n!==void 0&&(_=b(),p&&(i&&J(r),p(_)));var o;if(i?o=()=>{var u=e[r];return u===void 0?b():(l=!0,u)}:o=()=>{var u=e[r];return u!==void 0&&(a=void 0),u===void 0?a:u},i&&(s&N)===0)return o;if(p){var K=e.$$legacy;return(function(u,h){return arguments.length>0?((!i||!h||K||O)&&p(h?o():u),u):o()})}var w=!1,c=((s&ue)!==0?Q:W)(()=>(w=!1,o()));P&&(c.label=r),t&&v(c);var M=E;return(function(u,h){if(arguments.length>0){const g=h?v(c):i&&t?X(u):u;return A(c,g),w=!0,a!==void 0&&(a=g),u}return k&&w||(M.f&ee)!==0?c.v:v(c)})}export{we as a,xe as b,me as c,Ee as d,Pe as i,ge as l,ve as p,Oe as r,Re as s};
