import"./C5_K9giE.js";import"./C9jiJh7I.js";import{s,r as e}from"./CdWcIaq1.js";import{I as n}from"./D3Rjo6U9.js";function m(r,o){let t=e(o,["$$slots","$$events","$$legacy","icon"]);n(r,s({get icon(){return o.icon}},()=>t))}export{m as I};
