@keyframes svelte-1y1psx9-slide-up{0%{transform:translateY(100%);opacity:0}to{transform:translateY(0);opacity:1}}.animate-slide-up.svelte-1y1psx9{animation:svelte-1y1psx9-slide-up .3s ease-out}input[type=checkbox].svelte-1y1psx9:indeterminate{background-image:url("data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' fill='none' viewBox='0 0 16 16'%3e%3cpath stroke='white' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='M4 8h8'/%3e%3c/svg%3e");background-color:currentColor;background-size:100% 100%;background-position:center;background-repeat:no-repeat}.transition-all{transition-property:all;transition-timing-function:cubic-bezier(.4,0,.2,1);transition-duration:.2s}.inline-input{transition:all .2s ease}.inline-input:focus{box-shadow:0 0 0 3px #14b8a61a}body{overflow:hidden}
