import{f as u,a as h}from"../chunks/C5_K9giE.js";import{i as g}from"../chunks/Ddma7EHT.js";import{A as l,z as v,t as d,J as _,c as a,r as e,L as x}from"../chunks/C9jiJh7I.js";import{s as o}from"../chunks/C1C-UdLw.js";import{s as $,p}from"../chunks/D0i4Uc5a.js";const k={get error(){return p.error},get status(){return p.status}};$.updated.check;const m=k;var b=u("<h1> </h1> <p> </p>",1);function j(i,f){l(f,!1),g();var t=b(),r=v(t),c=a(r,!0);e(r);var s=x(r,2),n=a(s,!0);e(s),d(()=>{o(c,m.status),o(n,m.error?.message)}),h(i,t),_()}export{j as component};
